@@ -15,6 +15,11 @@ use hvcg_governance_openapi_catholic_polity::{Api, ApiNoContext, Client, Context
                       GetDioceseByIdResponse,
                       GetDiocesesResponse,
                       UpdateDioceseResponse,
+                      AddInstituteResponse,
+                      DeleteInstituteResponse,
+                      GetInstituteByIdResponse,
+                      GetInstitutesResponse,
+                      UpdateInstituteResponse,
                       AddParishResponse,
                       DeleteParishResponse,
                       GetParishByIdResponse,
@@ -52,6 +57,9 @@ fn main() {
                 "DeleteDiocese",
                 "GetDioceseById",
                 "GetDioceses",
+                "DeleteInstitute",
+                "GetInstituteById",
+                "GetInstitutes",
                 "AddParish",
                 "DeleteParish",
                 "GetParishById",
@@ -182,6 +190,43 @@ fn main() {
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
         */
+        /* Disabled because there's no example.
+        Some("AddInstitute") => {
+            let result = rt.block_on(client.add_institute(
+                  ???
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
+        */
+        Some("DeleteInstitute") => {
+            let result = rt.block_on(client.delete_institute(
+                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
+        Some("GetInstituteById") => {
+            let result = rt.block_on(client.get_institute_by_id(
+                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
+        Some("GetInstitutes") => {
+            let result = rt.block_on(client.get_institutes(
+                  Some("name_example".to_string()),
+                  Some(56),
+                  Some(56)
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
+        /* Disabled because there's no example.
+        Some("UpdateInstitute") => {
+            let result = rt.block_on(client.update_institute(
+                  serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example"),
+                  ???
+            ));
+            info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
+        },
+        */
         Some("AddParish") => {
             let result = rt.block_on(client.add_parish(
                   None
