@@ -57,6 +57,10 @@ pub struct Deanery {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -77,6 +81,7 @@ impl Deanery {
             diocese: diocese,
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -99,6 +104,12 @@ impl std::string::ToString for Deanery {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -133,6 +144,7 @@ impl std::str::FromStr for Deanery {
             pub diocese: Vec<models::Diocese>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -155,6 +167,7 @@ impl std::str::FromStr for Deanery {
                     "diocese" => intermediate_rep.diocese.push(<models::Diocese as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -171,6 +184,7 @@ impl std::str::FromStr for Deanery {
             diocese: intermediate_rep.diocese.into_iter().next().ok_or("diocese missing in Deanery".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Deanery".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
@@ -356,6 +370,10 @@ pub struct Diocese {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -376,6 +394,7 @@ impl Diocese {
             province: province,
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -398,6 +417,12 @@ impl std::string::ToString for Diocese {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -432,6 +457,7 @@ impl std::str::FromStr for Diocese {
             pub province: Vec<models::Province>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -454,6 +480,7 @@ impl std::str::FromStr for Diocese {
                     "province" => intermediate_rep.province.push(<models::Province as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -470,6 +497,7 @@ impl std::str::FromStr for Diocese {
             province: intermediate_rep.province.into_iter().next().ok_or("province missing in Diocese".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Diocese".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
@@ -651,6 +679,10 @@ pub struct Institute {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -670,6 +702,7 @@ impl Institute {
         Institute {
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -690,6 +723,12 @@ impl std::string::ToString for Institute {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -723,6 +762,7 @@ impl std::str::FromStr for Institute {
         struct IntermediateRep {
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -744,6 +784,7 @@ impl std::str::FromStr for Institute {
                 match key {
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -759,6 +800,7 @@ impl std::str::FromStr for Institute {
         std::result::Result::Ok(Institute {
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Institute".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
@@ -943,6 +985,10 @@ pub struct Parish {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -963,6 +1009,7 @@ impl Parish {
             deanery: deanery,
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -985,6 +1032,12 @@ impl std::string::ToString for Parish {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -1019,6 +1072,7 @@ impl std::str::FromStr for Parish {
             pub deanery: Vec<models::Deanery>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -1041,6 +1095,7 @@ impl std::str::FromStr for Parish {
                     "deanery" => intermediate_rep.deanery.push(<models::Deanery as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -1057,6 +1112,7 @@ impl std::str::FromStr for Parish {
             deanery: intermediate_rep.deanery.into_iter().next().ok_or("deanery missing in Parish".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Parish".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
@@ -1238,6 +1294,10 @@ pub struct Polity {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -1257,6 +1317,7 @@ impl Polity {
         Polity {
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -1277,6 +1338,12 @@ impl std::string::ToString for Polity {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -1310,6 +1377,7 @@ impl std::str::FromStr for Polity {
         struct IntermediateRep {
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -1331,6 +1399,7 @@ impl std::str::FromStr for Polity {
                 match key {
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -1346,6 +1415,7 @@ impl std::str::FromStr for Polity {
         std::result::Result::Ok(Polity {
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Polity".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
@@ -1405,6 +1475,10 @@ pub struct Province {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationEmail")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_email: Option<String>,
+
     #[serde(rename = "locationAddress")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub location_address: Option<String>,
@@ -1425,6 +1499,7 @@ impl Province {
             code: code,
             id: None,
             name: name,
+            location_email: None,
             location_address: None,
             location_name: None,
             person_in_charge: None,
@@ -1447,6 +1522,12 @@ impl std::string::ToString for Province {
         params.push(self.name.to_string());
 
 
+        if let Some(ref location_email) = self.location_email {
+            params.push("locationEmail".to_string());
+            params.push(location_email.to_string());
+        }
+
+
         if let Some(ref location_address) = self.location_address {
             params.push("locationAddress".to_string());
             params.push(location_address.to_string());
@@ -1481,6 +1562,7 @@ impl std::str::FromStr for Province {
             pub code: Vec<models::Code>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_email: Vec<String>,
             pub location_address: Vec<String>,
             pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
@@ -1503,6 +1585,7 @@ impl std::str::FromStr for Province {
                     "code" => intermediate_rep.code.push(<models::Code as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationEmail" => intermediate_rep.location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -1519,6 +1602,7 @@ impl std::str::FromStr for Province {
             code: intermediate_rep.code.into_iter().next().ok_or("code missing in Province".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Province".to_string())?,
+            location_email: intermediate_rep.location_email.into_iter().next(),
             location_address: intermediate_rep.location_address.into_iter().next(),
             location_name: intermediate_rep.location_name.into_iter().next(),
             person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
